"""Basic backend utility functions"""


def check_units(from_unit, to_unit, valid_units):
    """Check whether two units are both in a set.

    Parameters
    ----------
    from_unit : str
    to_unit : str
    valid_units : array_like of str
    """
    if from_unit not in valid_units:
        raise ValueError(f"Unit {from_unit} not in {valid_units}")
    if to_unit not in valid_units:
        raise ValueError(f"Unit {to_unit} not in {valid_units}")



"""User-facing functions."""
import numpy as np
from uxr.utils import check_units
from uxr.length.core import (
    UNITS,
    inches_to_feet,
    inches_to_yards,
)


def convert_unit(x, from_unit, to_unit):
    """Convert from one length unit to another.

    Parameters
    ----------
    x : array_like
        Lengths to convert.
    from_unit : {'in', 'ft', 'yd'}
        Unit of the input lengths `x`
    to_unit : {'in', 'ft', 'yd'}
        Unit of the returned lengths

    Returns
    -------
    ndarray
        An array of converted lengths with the same shape as `x`. If `x` is a
        0-d array, then a scalar is returned.
    """
    # check if units are valid length units
    check_units(from_unit, to_unit, UNITS)

    # convert length to inches
    if from_unit == "in":
        inches = x
    elif from_unit == "ft":
        inches = inches_to_feet(x, reverse=True)
    elif from_unit == "yd":
        inches = inches_to_yards(x, reverse=True)

    # convert inches to desired units
    if to_unit == "in":
        value = inches
    elif to_unit == "ft":
        value = inches_to_feet(inches)
    elif to_unit == "yd":
        value = inches_to_yards(inches)

    return value





"""Conversions between inches and larger imperial length units"""
INCHES_PER_FOOT = 12.0  # 12 inches in a foot
INCHES_PER_YARD = INCHES_PER_FOOT * 3.0  # 3 feet in a yard

UNITS = ("in", "ft", "yd")


def inches_to_feet(x, reverse=False):
    """Convert lengths between inches and feet.

    Parameters
    ----------
    x : array_like
        Lengths in feet.
    reverse : bool, optional
        If this is set to true this function converts from feet to inches
        instead of the default behaviour of inches to feet.

    Returns
    -------
    ndarray
        An array of converted lengths with the same shape as `x`. If `x` is a
        0-d array, then a scalar is returned.
    """
    if reverse:
        return x * INCHES_PER_FOOT
    else:
        return x / INCHES_PER_FOOT


def inches_to_yards(x, reverse=False):
    """Convert lengths between inches and yards.

    Parameters
    ----------
    x : array_like
        Lengths in feet.
    reverse : bool, optional
        If this is set to true this function converts from yards to inches
        instead of the default behaviour of inches to yards.

    Returns
    -------
    ndarray
        An array of converted lengths with the same shape as `x`. If `x` is a
        0-d array, then a scalar is returned.
    """
    if reverse:
        return x * INCHES_PER_YARD
    else:
        return x / INCHES_PER_YARD




from setuptools import setup, find_packages

setup(
    author="Joe Chelladurai",
    description="Quantiative User Experience Research",
    name="uxr",
    version="0.1.0",
    packages=find_packages(include=["uxr", "uxr.*"]),
    install_requires=['pandas>=1.0', 'scipy==1.1', 'matplotlib>=2.2.1,<3'],
    python_requires='>=2.7, !=3.0.*, !=3.1*',
)